Policy

Struct Policy 

pub struct Policy {
    pub confidentiality: i32,
    pub integrity: u32,
    pub deleted: bool,
    pub consent: bool,
}
Policy-related messages

Fields

confidentiality: i32integrity: u32deleted: boolconsent: bool

Implementations

Source

impl Policy

pub fn confidentiality(&self) -> Confidentiality

Returns the enum value of confidentiality, or the default if the field is set to an invalid enum value.

pub fn set_confidentiality(&mut self, value: Confidentiality)

Sets confidentiality to the provided enum value.